yt.visualization.plot\_modifications module
===========================================

.. automodule:: yt.visualization.plot_modifications
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
